==> am_mod_blg_0_1.zip: am_mod_blg_0_1/components/blg/template/barnraiser_01/entry_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<script type="text/javascript" src="speller/spellChecker.js"></script>

<script type="text/javascript">
	function openSpellChecker() {
		var speller = new spellChecker();
		speller.spellCheckAll();
	}
</script>

<script language="JavaScript" src="<?php echo $template_path_core;?>/js/imageHandling.js" type="text/javascript"></script>

<form action="index.php?amn=blg_entry_edit" method="post" name="frm" id="id_frm">
<input type="hidden" name="entry_id" value="<?php if(isset($entry['entry_id'])) { echo $entry['entry_id'];}?>" />
<input type="hidden" name="blog_id" value="<?php if(isset($blog['blog_id'])) { echo $blog['blog_id'];}?>" />


<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_entry'];?><br />
	</div>
		
	<div class="box_mid">
		<div class="content">
			<p>
				<label for="id_entry_title"><?php echo $lang['txt_title'];?></label>
				<input id="id_entry_title" class="input" style="width:480px;" type="text" name="entry_title" size="66" value="<?php if (isset($entry['entry_title'])) { echo $entry['entry_title'];}?>" />
				&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
				<br />
			</p>
			
			<p>
				<label for="id_entry_synopsis"><?php echo $lang['txt_synopsis'];?></label>
				<textarea id="id_entry_synopsis" style="width:480px;" name="entry_synopsis" cols="60" rows="1"><?php if (isset($entry['entry_synopsis'])) { echo $entry['entry_synopsis'];}?></textarea>
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('help.php?help=blog_item#edit');" />
				<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
				<br />
			</p>
			
			<?php
			if (isset($images)) {
			?>
			<table cellspacing="0" cellpadding="2" border="0" width="100%">
				<tr>
					<td valign="top">
						<label for="frm_file" style="width:105px;"><?php echo $lang['txt_image']; ?></label><br />
					</td>
					<td valign="top" width="100%">
						<select style="width:150px;" id="id_file_id" size=3 name="file_id" onChange='javascript:setimg(this)'>
							<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
							<?php
							$img_divs = "";
							foreach($images as $key => $i):
							$display_state = "none";
							$selected = "";
							if (isset($entry['file_id']) && $entry['file_id'] == $i['file_id']) {
								$selected = "selected=\"selected\"";
								$display_state = "block";
							}
							?>
							<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
							<?php
							$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view'] . "&amp;type=" . $i['type'] . "&amp;directory=" . $i['directory'] . "\" border=\"0\" class=\"picture\" /></div>";
							endforeach;
							?>
						</select>
					</td>
					<td valign="top" align="right">
						<?php echo $img_divs;?>
					</td>	
				</tr>
			</table>
			<?php }?>
			
			<p>
				<label for="id_entry_body"><?php echo $lang['txt_body'];?></label>
				<textarea id="id_entry_body" name="entry_body" cols="72" rows="8" style="width:480px;"><?php if (isset($entry['entry_body'])) { echo $entry['entry_body'];}?></textarea>
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=blg_blog#entry');" />
				<br />			
			</p>
			
			<?php
			$txtarea = "id_entry_body";
			$gui_editor_type = "max";
			include($template_path_core . "inc/form_gui_html_editor.inc.php");
			?>
		
			<hr />
						
			<p align="right">
				<?php
				if (isset($allow_spellcheck)) {
				?>
				<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
				&nbsp;
				<?php }?>
				
				<input type="submit" name="preview_entry" id="id_sub_preview" class="input_submit" value="<?php echo $lang['sub_preview'];?>" />
				&nbsp;
				<?php
				if (!empty($entry['entry_id'])) {
				?>
				<input type="submit" name="save_entry" id="id_sub_update" class="input_submit" value="<?php echo $lang['sub_update'];?>" />
				<?php
				}
				else {
				?>
				<input type="submit" name="save_entry" id="id_sub_insert" class="input_submit" value="<?php echo $lang['sub_insert'];?>" />
				<?php }?>
				<br />
			</p>
			
			<?php
			if (isset($entry['entry_body_preview'])) {
			?>
			<p>
				<?php echo $entry['entry_body_preview'];?><br />
			</p>
			<?php }?>
		</div>
	</div>
</div>
</form>

==> am_mod_blg_0_5.zip: am_mod_blg_0_5/components/blg/template/barnraiser_01/entry_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<script type="text/javascript" src="speller/spellChecker.js"></script>

<script type="text/javascript">
	function openSpellChecker() {
		var speller = new spellChecker();
		speller.spellCheckAll();
	}
</script>

<script language="JavaScript" src="<?php echo $template_path_core;?>/js/imageHandling.js" type="text/javascript"></script>

<form action="index.php?amn=blg_entry_edit" method="post" name="frm" id="id_frm">
<input type="hidden" name="entry_id" value="<?php if(isset($entry['entry_id'])) { echo $entry['entry_id'];}?>" />
<input type="hidden" name="blog_id" value="<?php if(isset($blog['blog_id'])) { echo $blog['blog_id'];}?>" />


<div class="box">
	<div class="box_top">
		<div class="content">
			<h1><?php echo $lang['hdr_entry'];?></h1>
		</div>
	</div>
		
	<div class="box_mid">
		<div class="content">
			<p>
				<b><?php echo $lang['txt_title_intro'];?></b><br />
			</p>
			
			<p>
				<label for="id_entry_title"><?php echo $lang['txt_title'];?></label>
				<input id="id_entry_title" class="input" style="width:480px;" type="text" name="entry_title" size="66" value="<?php if (isset($entry['entry_title'])) { echo $entry['entry_title'];}?>" />
				&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
				<br />
			</p>
			
			<p>
				<label for="id_entry_synopsis"><?php echo $lang['txt_synopsis'];?></label>
				<textarea id="id_entry_synopsis" style="width:480px;" name="entry_synopsis" cols="60" rows="1"><?php if (isset($entry['entry_synopsis'])) { echo $entry['entry_synopsis'];}?></textarea>
				<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
				<br />
			</p>

			<hr />
			
			<p>
				<b><?php echo $lang['txt_title_create'];?></b><br />
			</p>
			
			<table cellspacing="1" cellpadding="0" border="0" width="100%">
				<tr>
					<td>
						<label for="id_entry_body"><?php echo $lang['txt_body'];?></label><br />
					</td>
					<td>
						<?php
						$gui_expert_editor = "id_entry_body";
						include($template_path_core . "inc/form_gui_html_editor.inc.php");
						?>
					</td>
				</tr>
			</table>
				
			<table cellspacing="1" cellpadding="0" border="0" width="100%">
				<tr>
					<td width="1">
						<textarea id="id_entry_body" name="entry_body" cols="72" rows="8" style="width:480px;" onKeyUp="AMEditorSync(this.value, 'wysiwyg_editor');"><?php if (isset($entry['entry_body'])) { echo $entry['entry_body'];}?></textarea>
						<br />
					</td>
					<td>
						<br />
					</td>
					<td rowspan="2" valign="top" width="90%">
						<div id="editor_help"><?php echo $lang['txt_help_default'];?></div>
					</td>
				</tr>
				<tr>
					<td width="1">
						<iframe id="wysiwyg_editor" name="wysiwyg_editor" style="height:100px; width:480px;" frameborder="0" width="580"  scrolling="yes"  height="100">
			
						</iframe>
					</td>
					<td valign="top" width="20">
						<img src="<?php echo $template_path_core;?>img/arrow_up.png" width="9" height="12" alt="" border="0" onClick="AmEditorResize();" /><br />
						<img src="<?php echo $template_path_core;?>img/arrow_down.png" width="9" height="12" alt="" border="0" onClick="AmEditorResize('minus');" /><br />
						<img src="<?php echo $template_path_core;?>img/pixel.png" width="20" height="1" alt="" border="0" /><br />
					</td>
				</tr>
			</table>
			
			<script language="javascript" type="text/javascript">
				var wysiwygHeight = 100;
				var thisEditor = new AMEditor('id_entry_body', 'wysiwyg_editor');
			</script>
			
			<hr />
			
			<p>
				<b><?php echo $lang['txt_title_save'];?></b><br />
			</p>
				
			<p align="right">
				<?php
				if (isset($allow_spellcheck)) {
				?>
				<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
				&nbsp;
				<?php }?>
				
				<input type="submit" name="preview_entry" id="id_sub_preview" class="input_submit" value="<?php echo $lang['sub_preview'];?>" />
				&nbsp;
				<?php
				if (!empty($entry['entry_id'])) {
				?>
				<input type="submit" name="save_entry" id="id_sub_update" class="input_submit" value="<?php echo $lang['sub_update'];?>" />
				<?php
				}
				else {
				?>
				<input type="submit" name="save_entry" id="id_sub_insert" class="input_submit" value="<?php echo $lang['sub_insert'];?>" />
				<?php }?>
				<br />
			</p>
			
			<?php
			if (isset($entry['entry_body_preview'])) {
			?>
			<p>
				<?php echo $entry['entry_body_preview'];?><br />
			</p>
			<?php }?>
		</div>
	</div>
</div>
</form>
